summaryrefslogtreecommitdiffstats
path: root/ksplashml/themeengine
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:30:47 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:30:47 -0600
commitcc74f360bb40da3d79f58048f8e8611804980aa6 (patch)
treec4385d2c16b904757b1c8bb998a4aec6993373f7 /ksplashml/themeengine
parent79b21d47bce1ee428affc97534cd8b257232a871 (diff)
downloadtdebase-cc74f360bb40da3d79f58048f8e8611804980aa6.tar.gz
tdebase-cc74f360bb40da3d79f58048f8e8611804980aa6.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'ksplashml/themeengine')
-rw-r--r--ksplashml/themeengine/default/themelegacy.cpp4
-rw-r--r--ksplashml/themeengine/default/themelegacy.h4
-rw-r--r--ksplashml/themeengine/objkstheme.cpp18
-rw-r--r--ksplashml/themeengine/objkstheme.h8
-rw-r--r--ksplashml/themeengine/redmond/main.cpp2
-rw-r--r--ksplashml/themeengine/redmond/themeredmond.cpp6
-rw-r--r--ksplashml/themeengine/redmond/themeredmond.h2
-rw-r--r--ksplashml/themeengine/standard/themestandard.cpp2
-rw-r--r--ksplashml/themeengine/standard/themestandard.h2
-rw-r--r--ksplashml/themeengine/themeengine.h10
-rw-r--r--ksplashml/themeengine/unified/themeunified.cpp4
-rw-r--r--ksplashml/themeengine/unified/themeunified.h4
12 files changed, 33 insertions, 33 deletions
diff --git a/ksplashml/themeengine/default/themelegacy.cpp b/ksplashml/themeengine/default/themelegacy.cpp
index de8aac2b5..39839cca6 100644
--- a/ksplashml/themeengine/default/themelegacy.cpp
+++ b/ksplashml/themeengine/default/themelegacy.cpp
@@ -31,7 +31,7 @@
#include "themelegacy.h"
#include "themelegacy.moc"
-DefaultConfig::DefaultConfig( TQWidget *parent, KConfig *config )
+DefaultConfig::DefaultConfig( TQWidget *parent, TDEConfig *config )
:ThemeEngineConfig( parent, config )
{
mConfig->setGroup( TQString("KSplash Theme: Default") );
@@ -200,7 +200,7 @@ void ThemeDefault::_readSettings()
if( !mTheme )
return;
- KConfig *cfg = mTheme->themeConfig();
+ TDEConfig *cfg = mTheme->themeConfig();
if( !cfg )
return;
diff --git a/ksplashml/themeengine/default/themelegacy.h b/ksplashml/themeengine/default/themelegacy.h
index 852425414..0f73e80c1 100644
--- a/ksplashml/themeengine/default/themelegacy.h
+++ b/ksplashml/themeengine/default/themelegacy.h
@@ -28,7 +28,7 @@ class DefaultConfig: public ThemeEngineConfig
{
Q_OBJECT
public:
- DefaultConfig( TQWidget *, KConfig * );
+ DefaultConfig( TQWidget *, TDEConfig * );
void save();
protected:
TQCheckBox *mFlash, *mAlwaysShow;
@@ -45,7 +45,7 @@ public:
ThemeDefault( TQWidget *, const char *, const TQStringList& );
virtual ~ThemeDefault();
- inline const DefaultConfig *config( TQWidget *p, KConfig *c )
+ inline const DefaultConfig *config( TQWidget *p, TDEConfig *c )
{
return new DefaultConfig( p, c );
};
diff --git a/ksplashml/themeengine/objkstheme.h b/ksplashml/themeengine/objkstheme.h
index 4d88276ba..34ea2fdf1 100644
--- a/ksplashml/themeengine/objkstheme.h
+++ b/ksplashml/themeengine/objkstheme.h
@@ -17,7 +17,7 @@
#include <tqstring.h>
#include <tqstringlist.h>
-class KConfig;
+class TDEConfig;
/**
* @short Theme reader.
* A Theme is read in from the file
@@ -37,7 +37,7 @@ public:
TQString theme() const { return( mActiveTheme ); }
TQString themeEngine() const { return( mThemeEngine ); }
- KConfig *themeConfig() const { return( mThemeConfig ); }
+ TDEConfig *themeConfig() const { return( mThemeConfig ); }
TQString themeDir() const { return( mThemeDir ); }
bool loColor() const { return( mLoColor ); }
bool testing() const { return( mTesting ); }
@@ -50,11 +50,11 @@ public:
protected:
bool loadThemeRc( const TQString&, bool );
bool loadLocalConfig( const TQString&, bool );
- bool loadKConfig( KConfig *, const TQString&, bool );
+ bool loadTDEConfig( TDEConfig *, const TQString&, bool );
private:
TQString mActiveTheme, mThemeDir;
- KConfig *mThemeConfig;
+ TDEConfig *mThemeConfig;
int mXineramaScreen;
bool mLoColor, mTesting, mManagedMode;
diff --git a/ksplashml/themeengine/redmond/main.cpp b/ksplashml/themeengine/redmond/main.cpp
index 3f4dc0124..7b4a6bb2e 100644
--- a/ksplashml/themeengine/redmond/main.cpp
+++ b/ksplashml/themeengine/redmond/main.cpp
@@ -20,7 +20,7 @@
extern "C"
{
- ThemeEngineConfig *KsThemeConfig( TQWidget *parent, KConfig *config )
+ ThemeEngineConfig *KsThemeConfig( TQWidget *parent, TDEConfig *config )
{
return new CfgRedmond( parent, config );
}
diff --git a/ksplashml/themeengine/redmond/themeredmond.cpp b/ksplashml/themeengine/redmond/themeredmond.cpp
index 5e5bf1031..0328c0365 100644
--- a/ksplashml/themeengine/redmond/themeredmond.cpp
+++ b/ksplashml/themeengine/redmond/themeredmond.cpp
@@ -41,7 +41,7 @@
K_EXPORT_COMPONENT_FACTORY( ksplashredmond, KGenericFactory<ThemeRedmond>( "ksplash" ) )
-CfgRedmond::CfgRedmond( TQWidget *p, KConfig *c )
+CfgRedmond::CfgRedmond( TQWidget *p, TDEConfig *c )
:ThemeEngineConfig( p, c )
{
TQVBox *vbox = new TQVBox( this );
@@ -195,7 +195,7 @@ void ThemeRedmond::_initUi()
const int fUserOnly = fUserFirst+1;
int faceSource = fAdminOnly;
- KConfig *tdmconfig = new KConfig("tdm/tdmrc", true);
+ TDEConfig *tdmconfig = new TDEConfig("tdm/tdmrc", true);
tdmconfig->setGroup("X-*-Greeter");
TQString userPicsDir = tdmconfig->readEntry( "FaceDir", TDEGlobal::dirs()->resourceDirs("data").last() + "tdm/faces" ) + '/';
TQString fs = tdmconfig->readEntry( "FaceSource" );
@@ -313,7 +313,7 @@ void ThemeRedmond::_readSettings()
if( !mTheme )
return;
- KConfig *cfg = mTheme->themeConfig();
+ TDEConfig *cfg = mTheme->themeConfig();
if( !cfg )
return;
diff --git a/ksplashml/themeengine/redmond/themeredmond.h b/ksplashml/themeengine/redmond/themeredmond.h
index 6f8cc1550..c2ce0a6f3 100644
--- a/ksplashml/themeengine/redmond/themeredmond.h
+++ b/ksplashml/themeengine/redmond/themeredmond.h
@@ -25,7 +25,7 @@ class CfgRedmond: public ThemeEngineConfig
{
Q_OBJECT
public:
- CfgRedmond( TQWidget *, KConfig * );
+ CfgRedmond( TQWidget *, TDEConfig * );
protected:
TQCheckBox *mShowUsername;
diff --git a/ksplashml/themeengine/standard/themestandard.cpp b/ksplashml/themeengine/standard/themestandard.cpp
index a7c41692f..26c47eea0 100644
--- a/ksplashml/themeengine/standard/themestandard.cpp
+++ b/ksplashml/themeengine/standard/themestandard.cpp
@@ -135,7 +135,7 @@ void ThemeStandard::_readSettings()
if ( !mTheme )
return;
- KConfig *cfg = mTheme->themeConfig();
+ TDEConfig *cfg = mTheme->themeConfig();
if ( !cfg )
return;
diff --git a/ksplashml/themeengine/standard/themestandard.h b/ksplashml/themeengine/standard/themestandard.h
index 2e5d1aeb0..a1fb61ccf 100644
--- a/ksplashml/themeengine/standard/themestandard.h
+++ b/ksplashml/themeengine/standard/themestandard.h
@@ -45,7 +45,7 @@ class ThemeStandard: public ThemeEngine
Q_OBJECT
public:
ThemeStandard( TQWidget *, const char*, const TQStringList& );
- //inline const ThemeEngineConfig *config( TQWidget *p, KConfig *kc ) { return 0L; }
+ //inline const ThemeEngineConfig *config( TQWidget *p, TDEConfig *kc ) { return 0L; }
public slots:
inline void slotUpdateProgress( int i )
diff --git a/ksplashml/themeengine/themeengine.h b/ksplashml/themeengine/themeengine.h
index 026351b5b..fa2f15a65 100644
--- a/ksplashml/themeengine/themeengine.h
+++ b/ksplashml/themeengine/themeengine.h
@@ -18,7 +18,7 @@
#include <kdemacros.h>
-class KConfig;
+class TDEConfig;
class ObjKsTheme;
class TQMouseEvent;
@@ -30,18 +30,18 @@ class KDE_EXPORT ThemeEngineConfig: public TQVBox
Q_OBJECT
public:
- ThemeEngineConfig( TQWidget *p, KConfig *c )
+ ThemeEngineConfig( TQWidget *p, TDEConfig *c )
:TQVBox( p ), mConfig( c )
{}
- KConfig* config()const { return mConfig; }
+ TDEConfig* config()const { return mConfig; }
public slots:
virtual void load() {}
virtual void save() {}
protected:
- KConfig *mConfig;
+ TDEConfig *mConfig;
};
/**
@@ -54,7 +54,7 @@ class KDE_EXPORT ThemeEngine: public TQVBox
public:
ThemeEngine( TQWidget *parent, const char *name, const TQStringList &args );
virtual ~ThemeEngine() = 0;
- virtual const ThemeEngineConfig *config( TQWidget *, KConfig * ) { return 0L; }
+ virtual const ThemeEngineConfig *config( TQWidget *, TDEConfig * ) { return 0L; }
virtual ObjKsTheme *ksTheme() { return mTheme; }
virtual bool eventFilter( TQObject* o, TQEvent* e );
diff --git a/ksplashml/themeengine/unified/themeunified.cpp b/ksplashml/themeengine/unified/themeunified.cpp
index 1e86054f7..21c899adc 100644
--- a/ksplashml/themeengine/unified/themeunified.cpp
+++ b/ksplashml/themeengine/unified/themeunified.cpp
@@ -32,7 +32,7 @@
#include "themeunified.h"
#include "themeunified.moc"
-UnifiedConfig::UnifiedConfig( TQWidget *parent, KConfig *config )
+UnifiedConfig::UnifiedConfig( TQWidget *parent, TDEConfig *config )
:ThemeEngineConfig( parent, config )
{
mConfig->setGroup( TQString("KSplash Theme: Default") );
@@ -91,7 +91,7 @@ void ThemeUnified::_readSettings()
if( !mTheme )
return;
- KConfig *cfg = mTheme->themeConfig();
+ TDEConfig *cfg = mTheme->themeConfig();
if( !cfg )
return;
diff --git a/ksplashml/themeengine/unified/themeunified.h b/ksplashml/themeengine/unified/themeunified.h
index a8f9e12e2..cd6a1d1ca 100644
--- a/ksplashml/themeengine/unified/themeunified.h
+++ b/ksplashml/themeengine/unified/themeunified.h
@@ -30,7 +30,7 @@ class UnifiedConfig: public ThemeEngineConfig
{
Q_OBJECT
public:
- UnifiedConfig( TQWidget *, KConfig * );
+ UnifiedConfig( TQWidget *, TDEConfig * );
void save();
protected:
TQCheckBox *mAlwaysShow;
@@ -47,7 +47,7 @@ public:
ThemeUnified( TQWidget *, const char *, const TQStringList& );
virtual ~ThemeUnified();
- inline const UnifiedConfig *config( TQWidget *p, KConfig *c )
+ inline const UnifiedConfig *config( TQWidget *p, TDEConfig *c )
{
return new UnifiedConfig( p, c );
};
diff --git a/ksplashml/themeengine/objkstheme.cpp b/ksplashml/themeengine/objkstheme.cpp
index 533697dc4..df7556bac 100644
--- a/ksplashml/themeengine/objkstheme.cpp
+++ b/ksplashml/themeengine/objkstheme.cpp
@@ -32,7 +32,7 @@ ObjKsTheme::ObjKsTheme( const TQString& theme )
:mActiveTheme (theme), mThemeDir("/"), mThemeConfig (0L), mThemePrefix( "Themes/" ), d(0)
{
// Get Xinerama config.
- KConfig *config = kapp->config();
+ TDEConfig *config = kapp->config();
config->setGroup( "Xinerama" );
TQDesktopWidget *desktop = kapp->desktop();
mXineramaScreen = config->readNumEntry("KSplashScreen", desktop->primaryScreen());
@@ -63,7 +63,7 @@ bool ObjKsTheme::loadThemeRc( const TQString& activeTheme, bool force )
//kdDebug() << "ObjKsTheme::loadThemeRc: " << activeTheme << endl;
TQString prefix("Themes/");
TQString themeFile;
- KConfig *cf = 0L;
+ TDEConfig *cf = 0L;
// Try our best to find a theme file.
themeFile = locate( "appdata", prefix + activeTheme + "/" + TQString("Theme.rc") );
@@ -72,13 +72,13 @@ bool ObjKsTheme::loadThemeRc( const TQString& activeTheme, bool force )
themeFile = themeFile.isEmpty() ? locate("appdata",prefix+activeTheme+"/"+activeTheme+TQString(".rc")):themeFile;
if( !themeFile.isEmpty() )
- cf = new KConfig( themeFile );
+ cf = new TDEConfig( themeFile );
if( cf )
{
mActiveTheme = activeTheme;
mThemeDir = prefix + activeTheme+"/";
- if( loadKConfig( cf, activeTheme, force ) )
+ if( loadTDEConfig( cf, activeTheme, force ) )
{
mThemeConfig = cf;
return true;
@@ -92,14 +92,14 @@ bool ObjKsTheme::loadThemeRc( const TQString& activeTheme, bool force )
bool ObjKsTheme::loadLocalConfig( const TQString& activeTheme, bool force )
{
//kdDebug() << "ObjKsTheme::loadLocalConfig" << endl;
- KConfig *cfg = kapp->config();
- return( loadKConfig( cfg, activeTheme, force ) );
+ TDEConfig *cfg = kapp->config();
+ return( loadTDEConfig( cfg, activeTheme, force ) );
}
-// ObjKsConfig::loadKConfig(): Load our settings from a KConfig object.
-bool ObjKsTheme::loadKConfig( KConfig *cfg, const TQString& activeTheme, bool force )
+// ObjKsConfig::loadTDEConfig(): Load our settings from a TDEConfig object.
+bool ObjKsTheme::loadTDEConfig( TDEConfig *cfg, const TQString& activeTheme, bool force )
{
- //kdDebug() << "ObjKsTheme::loadKConfig" << endl;
+ //kdDebug() << "ObjKsTheme::loadTDEConfig" << endl;
if( !cfg )
return false;